@@ -386,7 +386,7 @@ def preprocess_dataframe(dataML, nclass=2):
     dataML = dataML.drop(['host_logmass', 'host_logmass_min', 'host_logmass_max','Hubble Residual', 'Transient AltName'],axis=1)
     dataML = dataML.drop(['rpsfQfPerfect'], axis=1)
     dataML = dataML.drop(['rApFillFac'], axis=1)
-    dataML = dataML.drop(['TransientRA', 'TransientDEC','NED_type', 'NED_name'], axis=1)
+    dataML = dataML.drop(['TransientRA', 'TransientDEC','NED_type', 'NED_name', 'class'], axis=1)
 
     #try dropping NED info now:
     dataML = dataML.drop(['NED_vel', 'NED_mag'], axis=1)
