@@ -652,9 +652,18 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle'):
     if verbose:
         print("Saving table of hosts to %s."%(path+"tables/FinalAssociationTable.csv"))
 
-    # re-calculate dist and dist/DLR values for the SN matched by gradient ascent
+    # re-calculate values for the SN matched by gradient ascent, to be used for classification
     #DLR = []
     #dist = []
+    host_DF = getColors(host_DF)
+    host_DF = calc_7DCD(host_DF)
+
+    host_DF['gApMag_gKronMag'] = host_DF['gApMag'] - host_DF['gKronMag']
+    host_DF['rApMag_rKronMag'] = host_DF['rApMag'] - host_DF['rKronMag']
+    host_DF['iApMag_iKronMag'] = host_DF['iApMag'] - host_DF['iKronMag']
+    host_DF['zApMag_zKronMag'] = host_DF['zApMag'] - host_DF['zKronMag']
+    host_DF['yApMag_yKronMag'] = host_DF['yApMag'] - host_DF['yKronMag']
+
     for idx, row in host_DF.iterrows():
         if row.dist != row.dist:
             try:
