@@ -5,6 +5,8 @@ from astro_ghost.TNSQueryFunctions import getTNSSpectra
 from astro_ghost.NEDQueryFunctions import getNEDSpectra
 from astro_ghost.ghostHelperFunctions import *
 from astropy.coordinates import SkyCoord
+from astro_ghost.classifier import loadClassifier, preprocess_dataframe
+from sklearn import preprocessing
 from astropy import units as u
 import pandas as pd
 from datetime import datetime
@@ -30,6 +32,15 @@ snCoord = [SkyCoord(14.162*u.deg, -9.90253*u.deg, frame='icrs'), \
 # if we have no match then it manually associates them.
 hosts = getTransientHosts(snName, snCoord, verbose=verbose, starcut='normal')
 
+# classify transients
+feature_list, dataML_preprocessed, labels_df2, names = preprocess_dataframe(hosts)
+dataML_matrix_scaled = preprocessing.scale(dataML_preprocessed)
+rf = load_classifier()
+names = hosts['TransientName'].values
+class_predictions = rf.predict(dataML_matrix_scaled, labels_df2.values)
+for i in np.arange(len(class_predictions)):
+    print("%s is predicted to be a %s." % (names[i], class_predictions[i]))
+
 #create directories to store the host spectra, the transient spectra, and the postage stamps
 hSpecPath = "./hostSpectra/"
 tSpecPath = "./SNspectra/"
@@ -39,12 +50,7 @@ for tempPath in paths:
     if not os.path.exists(tempPath):
         os.makedirs(tempPath)
 
-now = datetime.now()
-dateStr = "%i%.02i%.02i" % (now.year,now.month,now.day)
-rad = 30 #arcsec
-fn_SN = 'transients_%s.csv' % dateStr
-transients = pd.read_csv("./transients_%s/tables/%s"%(dateStr,fn_SN))
-
+transients = pd.DataFrame({'Name':snName, 'RA':[x.ra.deg for x in snCoord], 'DEC':[x.dec.deg for x in snCoord]})
 #get postage stamps and spectra
 getAllPostageStamps(hosts, 120, psPath, verbose) #get postage stamps of hosts
 getNEDSpectra(hosts, hSpecPath, verbose) #get spectra of hosts
